.. _using_cavcalc:

Using cavcalc
=============

This section explains how to use cavcalc via the command line and as a Python module.

.. toctree::
    :maxdepth: 1

    installation
    command_line
    module
    gfactors
